summaryrefslogtreecommitdiffstats
path: root/.config/nvim/lua/plugs-config/lualine.lua
diff options
context:
space:
mode:
authorJoe <rrbo@proton.me>2023-09-07 12:58:46 +0200
committerJoe <rrbo@proton.me>2023-09-07 12:58:46 +0200
commit280494040a53c1dc068ff86172777606d86ce388 (patch)
treee08732717167640d51b8ff224d36bae70707e783 /.config/nvim/lua/plugs-config/lualine.lua
parentup (diff)
downloaddotfiles-bsd-280494040a53c1dc068ff86172777606d86ce388.tar.gz
dotfiles-bsd-280494040a53c1dc068ff86172777606d86ce388.tar.bz2
dotfiles-bsd-280494040a53c1dc068ff86172777606d86ce388.tar.xz
dotfiles-bsd-280494040a53c1dc068ff86172777606d86ce388.tar.zst
dotfiles-bsd-280494040a53c1dc068ff86172777606d86ce388.zip
good
Diffstat (limited to '')
-rw-r--r--.config/nvim/lua/plugs-config/lualine.lua46
1 files changed, 39 insertions, 7 deletions
diff --git a/.config/nvim/lua/plugs-config/lualine.lua b/.config/nvim/lua/plugs-config/lualine.lua
index d577b54..b0458e9 100644
--- a/.config/nvim/lua/plugs-config/lualine.lua
+++ b/.config/nvim/lua/plugs-config/lualine.lua
@@ -157,12 +157,43 @@ ins_left {
show_filename_only = true,
hide_filename_extension = false,
show_modified_status = true,
- -- color = { fg = colors.darkblue },
- -- buffers_color = {
- -- -- Same values as the general color option can be used here.
- -- active = 'lualine_{section}_active', -- Color for active buffer.
- -- inactive = 'lualine_{section}_inactive', -- Color for inactive buffer.
- -- },
+ symbols = {
+ modified = ' ●', -- Text to show when the buffer is modified
+ alternate_file = '', -- Text to show to identify the alternate file
+ directory = '', -- Text to show when the buffer is a directory
+ },
+ -- color = { fg = colors.magenta },
+ buffers_color = {
+ -- Same values as the general color option can be used here.
+ active = function()
+ -- auto change color according to neovims mode
+ local mode_color = {
+ n = colors.green,
+ i = colors.blue,
+ v = colors.magenta,
+ [''] = colors.magenta,
+ V = colors.magenta,
+ c = colors.yellow,
+ no = colors.red,
+ s = colors.orange,
+ S = colors.orange,
+ [''] = colors.orange,
+ ic = colors.yellow,
+ R = colors.red,
+ Rv = colors.violet,
+ cv = colors.red,
+ ce = colors.red,
+ r = colors.cyan,
+ rm = colors.cyan,
+ ['r?'] = colors.cyan,
+ ['!'] = colors.red,
+ t = colors.red,
+ }
+ return { fg = mode_color[vim.fn.mode()], gui = 'bold' }
+ end,
+ -- active = { fg = colors.magenta, gui = 'bold' }, -- Color for active buffer.
+ -- inactive = { fg = colors.blue }, -- Color for inactive buffer.
+ },
}
ins_left {
@@ -197,7 +228,8 @@ ins_right {
local buf_ft = vim.api.nvim_buf_get_option(0, 'filetype')
local clients = vim.lsp.get_active_clients()
if next(clients) == nil then
- return msg
+ -- icon = ''
+ return
end
for _, client in ipairs(clients) do
local filetypes = client.config.filetypes